Addresser

Trait Addresser 

pub trait Addresser<K> {
    // Required methods
    fn compute(&self, key: &K) -> Result<String, AddresserError>;
    fn normalize(&self, key: &K) -> String;
}

Required Methods

fn compute(&self, key: &K) -> Result<String, AddresserError>

Returns a radix address calculated from the given key

Arguments
  • key - A natural key, as defined by K, used to calculate an address
fn normalize(&self, key: &K) -> String

Returns a human readable string of the given key

Arguments
  • key - A natural key, as defined by K

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors