pub struct SmartContractMetadata {
pub name: String,
pub version: String,
pub inputs: Vec<String>,
pub outputs: Vec<String>,
}Expand description
The metadata of a smart contract archive.
Fields
name: StringThe name of the smart contract.
version: StringThe version of the smart contract.
inputs: Vec<String>The list of input addresses used by this smart contract.
outputs: Vec<String>The list of output addresses used by this smart contract.