Struct transact::execution::executor::ExecutionTaskSubmitter [−][src]
pub struct ExecutionTaskSubmitter { /* fields omitted */ }Expand description
The interface for submitting execution tasks to the Executor.
Implementations
pub fn submit(
&self,
task_iterator: Box<dyn Iterator<Item = ExecutionTask> + Send>,
notifier: Box<dyn ExecutionTaskCompletionNotifier>
) -> Result<(), ExecutorError>
pub fn submit(
&self,
task_iterator: Box<dyn Iterator<Item = ExecutionTask> + Send>,
notifier: Box<dyn ExecutionTaskCompletionNotifier>
) -> Result<(), ExecutorError>
Submits an Iterator of Execution tasks and a completion notifier to the Executor for processing. The iterator provided will be consumed until either it is exhausted or the Executor is shutdown.
Errors
Returns an ExecutorError if the tasks cannot be successfully sent to the Executor, due to
the Executor being disconnected from this ExecutionTaskSubmitter.